/* ============================================================
 *
 * This file is a part of CCA project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <cmath>

#include <iostream>
#include <stdexcept>

#include <boost/shared_ptr.hpp>

#include <rsc/runtime/Printable.h>

#include <nemo/Vector.h>

namespace cca {

/**
 * Base for data transfer object, representing domain-specific data.
 * @defgroup DTO DataTransferObjects
 */
class DataTransferObject;
typedef boost::shared_ptr<DataTransferObject> DataTransferObjectPtr;
typedef boost::shared_ptr<void> VoidPtr;

/**
 * Base data transfer object, representing domain-specific data. All inheriting
 * classes should use the International System of Units (SI) as default data
 * representation.
 *
 * @ingroup DTO
 *
 * @todo overload operators (+=, -=, *= (), [])
 * @todo provide friend operators (+, -, *, /, !=, ==)
 */
class DataTransferObject {

public:

    /**
     * Prints the DataTransferObject
     *
     * @return DataTranserObject as String
     */
    virtual std::string print() const {
        std::string str;
        str = "<DataTransferObject>";
        return str;
    }

    /**
     * Implement this method and return a human-readable class name. This method
     * should always return the same class name. Its existence is an admission
     * to missing RTTI functionalities in C++.
     *
     * @return human-readable name of the class.
     */
    //virtual std::string getClassName() const = 0;
    /**
     * This method does the actual printing of class debug information and
     * should be overridden in subclasses.
     *
     * @param stream stream to print on
     */
//    virtual void printContents(std::ostream& stream) const {
//        stream << this->print();
//    }
protected:
    /**
     * Constructor
     * Initializes DTO with specified dimension.
     */
    DataTransferObject() {
    }

    virtual ~DataTransferObject() {
    }
};

inline std::ostream & operator<<(std::ostream &os,
        const DataTransferObject& dto) {
    os.precision(3); // Precision when printing double values
    os << dto.print();
    return os;
}

}
