/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "ControlAspect.h"

#include <sstream>
#include <algorithm>

using namespace std;

namespace rci {

ControlAspect::ControlAspect(const std::string &aname, const std::string &aID) :
    name(aname), ID(aID) {
}

ControlAspect::ControlAspect(const ControlAspect &orig) :
    name(orig.getName()), ID(orig.getID()) {
}

ControlAspect::~ControlAspect() {
}

std::string ControlAspect::getName() const {
    return this->name;
}

std::string ControlAspect::getID() const {
    return this->ID;
}

bool ControlAspect::equals(const ControlAspectPtr &mode) const {
    return (this->getID() == mode->getID());
}

bool ControlAspect::operator<(const ControlAspectPtr &compare) {
    return (this->getID() < compare->getID());
}

ControlAspectPtr ControlAspect::create(const std::string &name,
        const std::string &ID) {
    ControlAspectPtr mode(new ControlAspect(name, ID));
    return mode;
}

std::string ControlAspect::print() const {
    ostringstream outstream(ostringstream::out);
    outstream << "ControlAspect<" << ID << ">";
    return outstream.str();
}

}
