/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "rci/Controlled.h"

namespace rci {

ControlModePtr Controlled::getControlMode() {
	return this->_controlMode;
}

void Controlled::setControlMode(ControlModePtr controlMode) {
	this->_controlMode = controlMode;
}

Controlled::Controlled() :
		_controlMode() {
}

Controlled::~Controlled() {
}

bool PositionControlled::setJointPosition(JointAnglesPtr position) {
	_lastCommandedPosition = position;
	return true;
}

JointAnglesPtr PositionControlled::getLastPositionCommand() const {
	return this->_lastCommandedPosition;
}

PositionControlled::PositionControlled() :
		_lastCommandedPosition() {
}

PositionControlled::~PositionControlled() {
}

bool VelocityControlled::setJointVelocity(JointVelocitiesPtr velocity) {
	_lastCommandedVelocity = velocity;
	return true;
}

JointVelocitiesPtr VelocityControlled::getLastVelocityCommand() const {
	return this->_lastCommandedVelocity;
}

VelocityControlled::VelocityControlled() :
		_lastCommandedVelocity() {
}

VelocityControlled::~VelocityControlled() {
}

bool TorqueControlled::setJointTorque(JointTorquesPtr torque) {
	_lastCommandedTorque = torque;
	return true;
}

JointTorquesPtr TorqueControlled::getLastTorqueCommand() const {
	return this->_lastCommandedTorque;
}

TorqueControlled::TorqueControlled() :
		_lastCommandedTorque() {
}

TorqueControlled::~TorqueControlled() {
}

bool ImpedanceControlled::setJointImpedance(JointImpedancePtr impedance) {
	_lastCommandedImpedance = impedance;
	return true;
}

JointImpedancePtr ImpedanceControlled::getLastImpedanceCommand() const {
	return this->_lastCommandedImpedance;
}

ImpedanceControlled::ImpedanceControlled() :
		_lastCommandedImpedance() {
}

ImpedanceControlled::~ImpedanceControlled() {
}

bool PressureControlled::setPressure(PressurePtr pressure) {
	_lastCommandedPressure = pressure;
	return true;
}

PressurePtr PressureControlled::getLastPressureCommand() const {
	return this->_lastCommandedPressure;
}

PressureControlled::PressureControlled() :
		_lastCommandedPressure() {
}

PressureControlled::~PressureControlled() {
}

bool LengthControlled::setLength(LengthPtr length) {
	_lastCommandedLength = length;
	return true;
}

LengthPtr LengthControlled::getLastLengthCommand() const {
	return this->_lastCommandedLength;
}

LengthControlled::LengthControlled() :
		_lastCommandedLength() {
}

LengthControlled::~LengthControlled() {
}

bool PoseControlled::setPose(PosePtr pose) {
	_lastCommandedPose = pose;
	return true;
}

PosePtr PoseControlled::getLastPoseCommand() const {
	return this->_lastCommandedPose;
}

PoseControlled::PoseControlled() :
		_lastCommandedPose() {
}

PoseControlled::~PoseControlled() {
}

}
