/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "Sensing.h"

namespace rci {

void Sensing::update() {
	throw std::runtime_error("Not implemented.");
}

cca::DataTransferObjectPtr Sensing::get() const {
	throw std::runtime_error("Not implemented.");
}

Sensing::Sensing() {
}

Sensing::~Sensing() {
}

JointAnglesPtr PositionSensing::getJointPosition() const {
	return _latestJointPosition;
}

void PositionSensing::updateJointPosition(JointAnglesPtr angle) {
	this->_latestJointPosition = angle;
}

PositionSensing::PositionSensing(unsigned int dimension) :
		_latestJointPosition(
				new JointAngles(nemo::RealVector(nemo::dim(dimension), 0.0))) {
}

PositionSensing::~PositionSensing() {
}

JointVelocitiesPtr VelocitySensing::getVelocity() const {
	return _latestJointVelocity;
}

void VelocitySensing::updateJointVelocity(JointVelocitiesPtr vel) {
	this->_latestJointVelocity = vel;
}

VelocitySensing::VelocitySensing(unsigned int dimension) :
		_latestJointVelocity(
				new JointVelocities(
						nemo::RealVector(nemo::dim(dimension), 0.0))) {
}
VelocitySensing::~VelocitySensing() {
}

PressurePtr PressureSensing::getPressure() const {
	return _latestPressureValues;
}

PressureSensing::PressureSensing(unsigned int dimension) :
		_latestPressureValues(
				new Pressure(nemo::RealVector(nemo::dim(dimension), 0.0))) {
}

PressureSensing::~PressureSensing() {
}

LengthPtr LengthSensing::getLength() const {
	return _latestLengthValues;
}

LengthSensing::LengthSensing(unsigned int dimension) :
		_latestLengthValues(
				new Length(nemo::RealVector(nemo::dim(dimension), 0.0))) {
}
LengthSensing::~LengthSensing() {
}

ForcesPtr ForceSensing::getForces() const {
	if (!forces) {
		throw std::runtime_error(
				"[ForceSensing::getForces] No forces received yet!");
	}
	return forces;
}

void ForceSensing::updateForces(ForcesPtr force) {
	if (!force) {
		throw std::runtime_error(
				"[ForceSensing::updateForces] Null Pointer Exception!");
	}
	if (!forces) {
		forces = ForcesPtr(new Forces(*force));
	} else {
		forces->setValues(force->asDoubleVector());
	}
}

ForceSensing::ForceSensing() :
		forces(new Forces(nemo::RealVector(nemo::dim(3), 0.0))) {
}
ForceSensing::~ForceSensing() {
}

JointTorquesPtr TorqueSensing::getTorque() const {
	if (!torques) {
		throw std::runtime_error(
				"[TorqueSensing::getTorque] No torques received yet!");
	}
	return torques;
}

void TorqueSensing::updateTorque(JointTorquesPtr torque) {
	if (!torque) {
		throw std::runtime_error(
				"[TorqueSensing::updateTorque] Null Pointer Exception!");
	}
	this->torques->setValue(0, torque->asDouble(0));
}

TorqueSensing::TorqueSensing(unsigned int dimension) :
		torques(new JointTorques(nemo::RealVector(nemo::dim(dimension), 0.0))) {
}

TorqueSensing::~TorqueSensing() {
}

PowerPtr PowerSensing::getPower() const {
	return power;
}

PowerSensing::PowerSensing(unsigned int dimension) :
		power(new Power(nemo::RealVector(nemo::dim(dimension), 0.0))) {
}

PowerSensing::~PowerSensing() {
}

}
