/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>
#include <sstream>

// RSC
#include <rsc/math/MathUtils.h>

#include "rci/dto/CartesianPose.h"

namespace rci {

class Acceleration;
typedef boost::shared_ptr<Acceleration> AccelerationPtr;
class TranslationalAcceleration;
typedef boost::shared_ptr<TranslationalAcceleration> TranslationalAccelerationPtr;
class RotationalAcceleration;
typedef boost::shared_ptr<RotationalAcceleration> RotationalAccelerationPtr;

/**
 * Domain object, representing a cartesian
 * translatory velocity. Default representation is in \f$\frac{m}{s}\f$,
 * according to the International Unit System (SI).
 * @ingroup DTO
 */
class TranslationalAcceleration: public CartesianTranslational {

public:

    TranslationalAcceleration();
    TranslationalAcceleration(double valx, double valy, double valz);
    TranslationalAcceleration(nemo::RealVector values);
    ~TranslationalAcceleration();

    virtual double m_s2(unsigned int index);
    virtual nemo::RealVector m_s2Vector();

    /**
     * Shared Pointer Factory
     */
    static TranslationalAccelerationPtr fromM_s2(double x, double y, double z);
protected:
    /**
     * Printing the pose object
     * @return Textual representation of this pose.
     */
    virtual std::string print() const;
};

}
