/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "CartesianDamping.h"

using namespace nemo;

namespace rci {

TranslationalDamping::TranslationalDamping() :
    CartesianTranslational() {
}

TranslationalDamping::TranslationalDamping(double valx, double valy, double valz) :
    CartesianTranslational(valx, valy, valz) {
}

TranslationalDamping::TranslationalDamping(const TranslationalDamping& damping) :
    CartesianTranslational() {
    this->_values = RealVector(dim(3));
    this->_values[0] = damping.asDouble(0);
    this->_values[1] = damping.asDouble(1);
    this->_values[2] = damping.asDouble(2);
}

TranslationalDamping::TranslationalDamping(nemo::RealVector values) :
    CartesianTranslational(values) {
}

RotationalDamping::RotationalDamping() :
    CartesianRotational() {
}

RotationalDamping::RotationalDamping(double vala, double valb, double valc, double vald) :
    CartesianRotational(vala, valb, valc, vald) {
}

RotationalDamping::RotationalDamping(RealVector values) :
    CartesianRotational(values) {
}

RotationalDamping::RotationalDamping(const RotationalDamping& damping) :
    CartesianRotational() {
    this->_values = RealVector(damping.asDouble(0), damping.asDouble(1),
            damping.asDouble(2));
}

CartesianDamping::CartesianDamping() :
    CartesianValue() {
}

CartesianDamping::CartesianDamping(double valx, double valy, double valz,
        double vala, double valb, double valc, double vald) :
    CartesianValue(valx, valy, valz, vala, valb, valc, vald) {
}

CartesianDamping::CartesianDamping(const CartesianDamping& damping) :
    CartesianValue(damping) {
}

CartesianDamping::CartesianDamping(RealVector values) :
    CartesianValue(values) {
}

}
