/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "CartesianForces.h"

using namespace nemo;

namespace rci {

Forces::Forces() :
    CartesianTranslational() {
}

Forces::Forces(double valx, double valy, double valz) :
    CartesianTranslational(valx, valy, valz) {
}

Forces::Forces(const Forces& forces) :
    CartesianTranslational() {
    this->_values = RealVector(dim(3));
    this->_values[0] = forces.asDouble(0);
    this->_values[1] = forces.asDouble(1);
    this->_values[2] = forces.asDouble(2);
}

Forces::Forces(nemo::RealVector values) :
    CartesianTranslational(values) {
}

Torques::Torques() :
    CartesianRotational() {
}

Torques::Torques(double vala, double valb, double valc, double vald) :
    CartesianRotational(vala, valb, valc, vald) {
}

Torques::Torques(nemo::RealVector values) :
    CartesianRotational(values) {
}

Torques::Torques(const Torques& torques) :
    CartesianRotational() {
    this->_values = RealVector(torques.asDouble(0), torques.asDouble(1),
            torques.asDouble(2));
}

Wrench::Wrench() :
    CartesianValue() {
}

Wrench::Wrench(double valx, double valy, double valz, double vala,
        double valb, double valc, double vald) :
    CartesianValue(valx, valy, valz, vala, valb, valc, vald) {
}

Wrench::Wrench(const Wrench& wrench) :
    CartesianValue(wrench) {
}

Wrench::Wrench(nemo::RealVector values) :
    CartesianValue(values) {
}

}
