/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "CartesianStiffness.h"

using namespace nemo;

namespace rci {

TranslationalStiffness::TranslationalStiffness() :
    CartesianTranslational() {
}

TranslationalStiffness::TranslationalStiffness(double valx, double valy,
        double valz) :
    CartesianTranslational(valx, valy, valz) {
}

TranslationalStiffness::TranslationalStiffness(const TranslationalStiffness& transl) :
    CartesianTranslational() {
    this->_values = RealVector(dim(3));
    this->_values[0] = transl.asDouble(0);
    this->_values[1] = transl.asDouble(1);
    this->_values[2] = transl.asDouble(2);
}

TranslationalStiffness::TranslationalStiffness(nemo::RealVector values) :
    CartesianTranslational(values) {
}

RotationalStiffness::RotationalStiffness() :
    CartesianRotational() {
}

RotationalStiffness::RotationalStiffness(double vala, double valb, double valc, double vald) :
    CartesianRotational(vala, valb, valc, vald) {
}

RotationalStiffness::RotationalStiffness(nemo::RealVector values) :
    CartesianRotational(values) {
}

RotationalStiffness::RotationalStiffness(const RotationalStiffness& rot) :
    CartesianRotational() {
    this->_values = RealVector(rot.asDouble(0), rot.asDouble(1),
            rot.asDouble(2));
}

CartesianStiffness::CartesianStiffness() :
    CartesianValue() {
}

CartesianStiffness::CartesianStiffness(double valx, double valy, double valz,
        double vala, double valb, double valc, double vald) :
    CartesianValue(valx, valy, valz, vala, valb, valc, vald) {
}

CartesianStiffness::CartesianStiffness(const CartesianStiffness& intact) :
    CartesianValue(intact) {
}

CartesianStiffness::CartesianStiffness(nemo::RealVector values) :
    CartesianValue(values) {
}

}
