/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>

#include "rci/dto/CartesianValues.h"

namespace rci {

/**
 * Domain object, representing a cartesian force and rotatory stiffness in all
 * three dimensions. The default unit is newton per meter (\f$N/m\f$).
 * @ingroup DTO
 * @ingroup Compliance
 */
class TranslationalStiffness: public CartesianTranslational {

public:
    TranslationalStiffness();
    TranslationalStiffness(double x, double y, double z);
    TranslationalStiffness(nemo::RealVector values);
    TranslationalStiffness(const TranslationalStiffness& stiffness);
};

/**
 * Domain object, representing an orientation or rotational transformation in
 * cartesian space. The default unit is newton-metres per radian
 * (\f$N*m/rad\f$).
 * @ingroup DTO
 * @ingroup Compliance
 */
class RotationalStiffness: public CartesianRotational {

public:
    RotationalStiffness();
    RotationalStiffness(double a, double b, double c, double d);
    RotationalStiffness(nemo::RealVector values);
    RotationalStiffness(const RotationalStiffness& RotationalStiffness);
};

/**
 * Domain object, representing a full cartesian pose, consisting of
 * translational transformation and orientation.
 * @ingroup DTO
 * @ingroup Compliance
 */
class CartesianStiffness: public CartesianValue {

public:
    CartesianStiffness();
    CartesianStiffness(double x, double y, double z, double a, double b,
            double c, double d);
    CartesianStiffness(nemo::RealVector values);
    CartesianStiffness(const CartesianStiffness& intact);
};

}
