/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#pragma once

#include <iostream>
#include <sstream>
#include <boost/shared_ptr.hpp>

#include <cca/dto/DataTransferObject.h>
#include "cca/dto/ContainingDoubles.h"

namespace rci {

class Doubles;
typedef boost::shared_ptr<Doubles> DoublesPtr;

/**
 * Domain object, representing unspecified raw double values. Warning: Try to
 * use more specific DTOs to allow users to know the content and to use
 * domain-specific methods as provided by more specific DTOs.
 */
class Doubles: public cca::DataTransferObject, public cca::ContainingDoubles {

public:
    Doubles();
    Doubles(const nemo::RealVector& values);
    Doubles(double value);
    Doubles(unsigned int dim, double value);
    Doubles(const Doubles& values);

    /**
     * Creates shared pointer to new Doubles DTO with a single passed value.
     *
     * @param value
     *          Single value.
     */
    static DoublesPtr create(double value);

    /**
     * Creates shared pointer to new Doubles DTO with passed values.
     *
     * @param values
     *          Values to fill each end every field of the DTO.
     */
    static DoublesPtr create(const nemo::RealVector& values);

    /**
     * Create blank DoublesPtr with given dimension (and optionally fill it
     * with the given value, otherwise filled with zeros).
     *
     * @param dimension
     *          Dimension of the Doubles DTo to create
     * @param value
     *          Value to fill each end every field of the DTO (value in default
     *          representation - \f$rad\f$)
     */
    static DoublesPtr create(unsigned int dimension, double value = 0.0);

    /**
     * Create Doubles from a Doubles object (deep copy)
     *
     * @param Doubles object
     */
    static DoublesPtr copy(const Doubles&);

protected:
    /**
     * Print function
     */
    virtual std::string print() const;
};

}
