/* ============================================================
 *
 * This file is a part of RCI project
 *
 * Copyright (C) 2011 by Arne Nordmann <anordman at cor-lab dot uni-bielefeld dot de>
 *
 * This file may be licensed under the terms of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by:
 *   CoR-Lab, Research Institute for Cognition and Robotics
 *     Bielefeld University
 *
 * ============================================================ */

#include "Phase.h"

#include <sstream>
#include <math.h>
#include <boost/shared_ptr.hpp>

using namespace std;
using namespace nemo;
using namespace cca;

namespace rci {

Phase::Phase() :
        DataTransferObject(), ContainingDoubles() {
}

Phase::Phase(double value) :
        DataTransferObject(), ContainingDoubles(1) {
    this->setValue(value);
}

std::string Phase::print() const {
    ostringstream outstream(ostringstream::out);
    outstream.precision(3); // Precision when printing double values
    outstream << "Phase<";
    for (unsigned int i = 0; i < this->getDimension(); ++i) {
        if (i > 0) {
            outstream << ",";
        }
        outstream << this->asDouble(i);
    }
    outstream << ">(rad)" << std::endl;
    return outstream.str();
}

}
