#include <gtest/gtest.h>

#include <iostream>
#include <vector>
#include <boost/shared_ptr.hpp>

#include "rci/dto/CartesianForces.h"

using namespace nemo;
using namespace rci;

class WrenchTest: public ::testing::Test {
protected:

    WrenchTest() :
            values(), wrench() {
        values = RealVector(dim(7));
        values[0] = 1.12;
        values[1] = 2.0;
        values[2] = -1.1;
        values[3] = 1.0;
        values[4] = 34.0;
        values[5] = 0.0;
        values[6] = 0.0;
        wrench = Wrench(values);
    }

    virtual ~WrenchTest() {
    }

    RealVector values;
    Wrench wrench;
};

TEST_F(WrenchTest, testInitialization)
{
    EXPECT_EQ(7, Wrench().getDimension());
}

TEST_F(WrenchTest, testConstruction)
{
    // Check dimension
    Wrench i = Wrench(values);
    EXPECT_EQ(7, i.getDimension());

    // Check dimension
    i = Wrench(1, 2, 3, 4, 5, 6,7);
    EXPECT_EQ(7, i.getDimension());
}

TEST_F(WrenchTest, testValueGetter)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.12, wrench.asDouble(0));
    EXPECT_DOUBLE_EQ(-1.1, wrench.asDouble(2));
    EXPECT_DOUBLE_EQ(34.0, wrench.asDouble(4));

    // Check values vector
    testvalues = wrench.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[3], testvalues[3]);
    EXPECT_DOUBLE_EQ(values[5], testvalues[5]);
}

TEST_F(WrenchTest, testCartesianGetter)
{
    // Check position values
    EXPECT_DOUBLE_EQ(1.12, wrench.x());
    EXPECT_DOUBLE_EQ(2.0, wrench.y());
    EXPECT_DOUBLE_EQ(-1.1, wrench.z());

    // Check orientation values
    EXPECT_DOUBLE_EQ(1.00, wrench.q0());
    EXPECT_DOUBLE_EQ(34.0, wrench.q1());
    EXPECT_DOUBLE_EQ(0.0, wrench.q2());
    EXPECT_DOUBLE_EQ(0.0, wrench.q3());
}
