#include <gtest/gtest.h>

#include <iostream>
#include <vector>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/dto/CartesianImpedance.h"

using namespace nemo;
using namespace rci;

class CartesianImpedanceTest: public ::testing::Test {
protected:

    CartesianImpedanceTest() :
            values(), imped() {
        values = RealVector(dim(7));
        values[0] = 1.12;
        values[1] = 2.0;
        values[2] = -1.1;
        values[3] = 5 * M_PI;
        values[4] = 0.0;
        values[5] = -3 * M_PI;
        values[6] = 0.0;
        imped = CartesianImpedance(values);
    }

    virtual ~CartesianImpedanceTest() {
    }

    RealVector values;
    CartesianImpedance imped;
};

TEST_F(CartesianImpedanceTest, testInitialization)
{
    EXPECT_EQ(7, CartesianImpedance().getDimension());
}

TEST_F(CartesianImpedanceTest, testConstruction)
{
    // Check dimension
    CartesianImpedance i = CartesianImpedance(values);
    EXPECT_EQ(7, i.getDimension());

    // Check dimension
    i = CartesianImpedance(1, 2, 3, 4, 5, 6,7);
    EXPECT_EQ(7, i.getDimension());
}

TEST_F(CartesianImpedanceTest, testValueGetter)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(1.12, imped.asDouble(0));
    EXPECT_DOUBLE_EQ(-1.1, imped.asDouble(2));
    EXPECT_DOUBLE_EQ(0, imped.asDouble(4));

    // Check values vector
    testvalues = imped.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[3], testvalues[3]);
    EXPECT_DOUBLE_EQ(values[5], testvalues[5]);
}

TEST_F(CartesianImpedanceTest, testCartesianGetter)
{
    // Check position values
    EXPECT_DOUBLE_EQ(1.12, imped.x());
    EXPECT_DOUBLE_EQ(2.0, imped.y());
    EXPECT_DOUBLE_EQ(-1.1, imped.z());

    // Check orientation values
    EXPECT_DOUBLE_EQ(5 * M_PI, imped.q0());
    EXPECT_DOUBLE_EQ(0.0, imped.q1());
    EXPECT_DOUBLE_EQ(-3 * M_PI, imped.q2());
    EXPECT_DOUBLE_EQ(0.0, imped.q3());
}
