#include <gtest/gtest.h>

#include "rci/ControlMode.h"

using namespace rci;

class ControlModeTest: public ::testing::Test {
protected:

    ControlModeTest() :
            noCtrl(), posCtrl(), trqCtrl() {

        noCtrl = ControlMode::create("Off");

        posCtrl = ControlMode::create("PosCtrl");
        posCtrl->addControlAspect(jointPositionControl);

        trqCtrl = ControlMode::create("TrqCtrl");
        trqCtrl->addControlAspect(jointTorqueControl);

    }

    virtual ~ControlModeTest() {
    }

    ControlModePtr noCtrl;
    ControlModePtr posCtrl;
    ControlModePtr trqCtrl;
};

TEST_F(ControlModeTest, testConstruction)
{
    ControlModePtr c = ControlMode::create("TestMode");
    EXPECT_EQ(c->getName(), "TestMode");
}

TEST_F(ControlModeTest, testComparison)
{
    EXPECT_TRUE(posCtrl->equals(posCtrl));
    EXPECT_TRUE(trqCtrl->equals(trqCtrl));

    EXPECT_FALSE(posCtrl->equals(trqCtrl));
    EXPECT_FALSE(trqCtrl->equals(posCtrl));
}

TEST_F(ControlModeTest, testControlAspectSupport)
{
    EXPECT_TRUE(posCtrl->supports(jointPositionControl));
    EXPECT_TRUE(trqCtrl->supports(jointTorqueControl));

    EXPECT_FALSE(trqCtrl->supports(jointPositionControl));
    EXPECT_FALSE(posCtrl->supports(jointTorqueControl));
}

TEST_F(ControlModeTest, testCombination)
{
    ControlModePtr comb = posCtrl->combineWith(trqCtrl, "PosTrq");

    EXPECT_TRUE(comb->supports(jointPositionControl));
    EXPECT_TRUE(comb->supports(jointTorqueControl));

    std::cout << comb->print();

    EXPECT_FALSE(comb->supports(noControl));
}

TEST_F(ControlModeTest, testPoseControl)
{
    EXPECT_TRUE(poseControl->equals(poseControl));
    EXPECT_FALSE(poseControl->equals(jointPositionControl));
}

TEST_F(ControlModeTest, testJointPositionControl)
{
    EXPECT_TRUE(jointPositionControl->equals(jointPositionControl));
    EXPECT_FALSE(jointPositionControl->equals(poseControl));
}

TEST_F(ControlModeTest, testCommutativeProperty)
{
    ControlModePtr cmA = ControlMode::create("A");
    ControlModePtr cmB = ControlMode::create("B");

    // Combine
    ControlModePtr cmC = cmA->combineWith(cmB, "AB");
    ControlModePtr cmD = cmA->combineWith(cmB, "BA");

    // Should result in the same Control Mode
    EXPECT_TRUE(cmC->equals(cmD));
    EXPECT_TRUE(cmD->equals(cmC));
}
