#include <gtest/gtest.h>

#include <iostream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/dto/JointImpedance.h"

using namespace nemo;
using namespace rci;

class JointStiffnessTest: public ::testing::Test {
protected:

    JointStiffnessTest() :
            values(), js() {
        values = RealVector(dim(3));
        values[0] = 1.2 * M_PI;
        values[1] = -3 * M_PI;
        values[2] = -2 * M_PI;
        js = JointStiffness(values);
    }

    virtual ~JointStiffnessTest() {
    }

    RealVector values;
    JointStiffness js;
};

TEST_F(JointStiffnessTest, isEmptyInitially)
{
    EXPECT_EQ(0, JointStiffness().getDimension());
}

TEST_F(JointStiffnessTest, testConstruction)
{
    // Check dimension
    JointStiffness j = JointStiffness(-1.2);
    EXPECT_EQ(1, j.getDimension());

    // Check dimension
    j = JointStiffness(values);
    EXPECT_EQ(3, j.getDimension());
}

TEST_F(JointStiffnessTest, testGetters)
{
    RealVector testvalues;

    // Check double getters
    EXPECT_DOUBLE_EQ(1.2 * M_PI, js.asDouble(0));
    EXPECT_DOUBLE_EQ(-3 * M_PI, js.asDouble(1));
    EXPECT_DOUBLE_EQ(-2 * M_PI, js.asDouble(2));

    // Check operator[]
    EXPECT_DOUBLE_EQ(1.2 * M_PI, js[0].asDouble(0));
    EXPECT_DOUBLE_EQ(-3 * M_PI, js[1].asDouble(0));
    EXPECT_DOUBLE_EQ(-2 * M_PI, js[2].asDouble(0));

    // Check vector getter
    testvalues = js.asDoubleVector();
    EXPECT_DOUBLE_EQ(values[0], testvalues[0]);
    EXPECT_DOUBLE_EQ(values[1], testvalues[1]);
    EXPECT_DOUBLE_EQ(values[2], testvalues[2]);
}
