#include <gtest/gtest.h>

#include <iostream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/dto/Phase.h"
#include "rci/dto/converter/PhaseConverter.h"

using namespace nemo;
using namespace std;
using namespace cca;
using namespace cca::rci;
using namespace rsb::converter;
using namespace rst::converter::rci;

class PhaseTest: public ::testing::Test {
protected:

    PhaseTest() {
        value1 = 1.234;
        value2 = M_PI;
        phi = Phase(value1);
    }

    virtual ~PhaseTest() {
    }

    double value1, value2;
    Phase phi;
};

TEST_F(PhaseTest, isEmptyInitially)
{
    EXPECT_EQ(0, Phase().getDimension());
}

TEST_F(PhaseTest, testConstruction)
{
    // Check dimension
    Phase j = Phase(0.0);
    EXPECT_EQ(1, j.getDimension());
}

TEST_F(PhaseTest, testGetters)
{
    RealVector testvalues;

    // Check example values
    EXPECT_DOUBLE_EQ(value1, phi.asDouble(0));
}

TEST_F(PhaseTest, testConversion)
{
    // Converter construction
    PhaseConverter conv = PhaseConverter();
    // Input data for converter (put into shared_ptr but don't delete it afterwards)
    AnnotatedData data = make_pair(rsc::runtime::typeName<Phase>(),boost::shared_ptr<void>(&phi,rsc::misc::NullDeleter()));
    // Convert to wire and back
    string wire;
    string schema = conv.serialize(data, wire);
    AnnotatedData result = conv.deserialize(schema, wire);

    // Check equality
    EXPECT_NEAR(phi.getDimension(), (boost::static_pointer_cast<Phase>(result.second))->getDimension(), 0.000001);
    EXPECT_NEAR(phi.asDouble(0), (boost::static_pointer_cast<Phase>(result.second))->asDouble(0), 0.000001);
}

