#include <gtest/gtest.h>

#include <iostream>
#include <math.h>
#include <boost/shared_ptr.hpp>

#include "rci/ResourceNode.h"
#include "rci/Sensing.h"
#include "rci/Controlled.h"

using namespace nemo;
using namespace rci;

class CartesianNode: public ResourceNode,
        public Sensing,
        public PoseSensing,
        public CartesianVelocitySensing,
        public CartesianAccelerationSensing {
public:
    CartesianNode() :
            ResourceNode("Cartesian Sensing Node"), Sensing(), PoseSensing(),
                    CartesianVelocitySensing(), CartesianAccelerationSensing() {
    }
    virtual ~CartesianNode() {
    }
};

class NodeCastingTest: public ::testing::Test {
protected:

    NodeCastingTest() :
            cart() {
        cart = boost::shared_ptr<CartesianNode>(new CartesianNode());
    }

    virtual ~NodeCastingTest() {
    }

    boost::shared_ptr<CartesianNode> cart;
};

TEST_F(NodeCastingTest, testCastToSensing) {
    EXPECT_TRUE(boost::dynamic_pointer_cast<Sensing>(cart));
    EXPECT_TRUE(boost::dynamic_pointer_cast<PoseSensing>(cart));
    EXPECT_TRUE(boost::dynamic_pointer_cast<CartesianVelocitySensing>(cart));

    EXPECT_FALSE(boost::dynamic_pointer_cast<ForceSensing>(cart));
}

TEST_F(NodeCastingTest, testCastToControlled) {
    EXPECT_FALSE(boost::dynamic_pointer_cast<Controlled>(cart));
    EXPECT_FALSE(boost::dynamic_pointer_cast<PoseControlled>(cart));
}
